# PathologyFoundation

<div style="text-align:center"><img src="figures/logo.png" width=300/></div>

[![license](https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000)](https://github.com/pathologyfoundation/PathologyFoundation/blob/master/LICENSE)

## Installation

* From PyPI

```bash
pip install pathologyfoundation
```